"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MeetingHudVoteCastEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player casts a vote on another player or skips vote in a
 * meeting.
 */
class MeetingHudVoteCastEvent extends events_1.RevertableEvent {
    constructor(room, meetinghud, message, 
    /**
     * The player that cast the vote.
     */
    voter, 
    /**
     * The player that the voter voted for.
     */
    suspect) {
        super();
        this.room = room;
        this.meetinghud = meetinghud;
        this.message = message;
        this.voter = voter;
        this.suspect = suspect;
        this.eventName = "meeting.castvote";
        this._alteredVoter = voter;
        this._alteredSuspect = suspect;
    }
    /**
     * Whether the voter skipped the vote.
     */
    get didSkip() {
        return this._alteredSuspect === undefined;
    }
    /**
     * The altered player that will cast the vote instead, if changed.
     */
    get alteredVoter() {
        return this._alteredVoter;
    }
    /**
     * The altered player that the voter voted for instead, if changed.
     */
    get alteredSuspect() {
        return this._alteredSuspect;
    }
    /**
     * Change the player that cast the vote.
     * @param voter The player to cast the vote.
     */
    setVoter(voter) {
        this._alteredVoter = voter;
    }
    /**
     * Change the player that the voter voted for.
     * @param suspect The player for the voter to vote for.
     */
    setSuspect(suspect) {
        this._alteredSuspect = suspect;
    }
}
exports.MeetingHudVoteCastEvent = MeetingHudVoteCastEvent;
MeetingHudVoteCastEvent.eventName = "meeting.castvote";
//# sourceMappingURL=VoteCast.js.map