"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetColorEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player color updated.
 */
class PlayerSetColorEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The color that the player had before.
     */
    oldColor, 
    /**
     * The new color that the player has.
     */
    newColor) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldColor = oldColor;
        this.newColor = newColor;
        this.eventName = "player.setcolor";
        this._alteredColor = newColor;
    }
    /**
     * The altered color that the player will have set instead, if changed.
     */
    get alteredColor() {
        return this._alteredColor;
    }
    /**
     * Revert the player's color back to their old color.
     */
    revert() {
        this.setColor(this.oldColor);
    }
    /**
     * Change the color that the player had set.
     * @param color The color to set.
     */
    setColor(color) {
        this._alteredColor = color;
    }
}
exports.PlayerSetColorEvent = PlayerSetColorEvent;
PlayerSetColorEvent.eventName = "player.setcolor";
//# sourceMappingURL=SetColor.js.map